@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,14 +60,14 @@ import com.openexchange.messaging.MessagingPermissions;
 
 /**
  * {@link TwitterMessagingFolder}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class TwitterMessagingFolder implements MessagingFolder {
 
     /**
      * Gets the instance.
-     * 
+     *
      * @param user The user ID
      * @return The instance
      */
@@ -85,11 +85,8 @@ public final class TwitterMessagingFolder implements MessagingFolder {
     private TwitterMessagingFolder(final int user) {
         super();
         final MessagingPermission mp = DefaultMessagingPermission.newInstance();
-        mp.setAllPermissions(
-            MessagingPermission.READ_FOLDER,
-            MessagingPermission.READ_ALL_OBJECTS,
-            MessagingPermission.NO_PERMISSIONS,
-            MessagingPermission.DELETE_OWN_OBJECTS);
+        final int[] arr = TwitterMessagingService.getStaticRootPerms();
+        mp.setAllPermissions(arr[0], arr[1], arr[2], arr[3]);
         mp.setAdmin(false);
         mp.setEntity(user);
         mp.setGroup(false);
