@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,7 +74,7 @@ import com.openexchange.twitter.TwitterException;
 
 /**
  * {@link TwitterMessagingMessageAccess}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class TwitterMessagingMessageAccess implements MessagingMessageAccess {
@@ -102,6 +102,8 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
 
     private final int cid;
 
+    private final Session session;
+
     /**
      * Initializes a new {@link TwitterMessagingMessageAccess}.
      */
@@ -111,6 +113,7 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
         id = account.getId();
         user = session.getUserId();
         cid = session.getContextId();
+        this.session = session;
     }
 
     public MessagingPart getAttachment(final String folder, final String messageId, final String sectionId) throws MessagingException {
@@ -151,9 +154,9 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
             throw new MessagingException(e);
         }
     }
-    
-    private TwitterMessagingMessage get(long id) throws TwitterException {
-        return new TwitterMessagingMessage(twitterAccess.showStatus(id));
+
+    private TwitterMessagingMessage get(final long id) throws TwitterException {
+        return new TwitterMessagingMessage(twitterAccess.showStatus(id), session);
     }
 
     public List<MessagingMessage> getMessages(final String folder, final String[] messageIds, final MessagingField[] fields) throws MessagingException {
@@ -161,16 +164,16 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
         try {
             final long[] ids = strings2longs(messageIds);
             final List<MessagingMessage> l = new ArrayList<MessagingMessage>(ids.length);
-            for (int i = 0; i < ids.length; i++) {
-                l.add(get(ids[i]));
+            for (final long id2 : ids) {
+                l.add(get(id2));
             }
             return l;
         } catch (final TwitterException e) {
             throw new MessagingException(e);
         }
     }
-    
-    
+
+
 
     public List<String> moveMessages(final String sourceFolder, final String destFolder, final String[] messageIds, final boolean fast) throws MessagingException {
         checkFolder(sourceFolder);
@@ -230,19 +233,19 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
         try {
             final List<MessagingMessage> msgs;
             if (null != searchTerm) {
-                final List<Status> friendsTimeline = twitterAccess.getFriendsTimeline();
+                final List<Status> friendsTimeline = twitterAccess.getHomeTimeline();
                 msgs = new ArrayList<MessagingMessage>(friendsTimeline.size());
                 for (final Status status : friendsTimeline) {
-                    final TwitterMessagingMessage message = new TwitterMessagingMessage(status);
+                    final TwitterMessagingMessage message = new TwitterMessagingMessage(status, session);
                     if (searchTerm.matches(message)) {
                         msgs.add(message);
                     }
                 }
             } else {
-                final List<Status> friendsTimeline = twitterAccess.getFriendsTimeline();
+                final List<Status> friendsTimeline = twitterAccess.getHomeTimeline();
                 msgs = new ArrayList<MessagingMessage>(friendsTimeline.size());
                 for (final Status status : friendsTimeline) {
-                    TwitterMessagingMessage message = new TwitterMessagingMessage(status);
+                    final TwitterMessagingMessage message = new TwitterMessagingMessage(status, session);
                     msgs.add(message);
                }
             }
@@ -250,7 +253,7 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
              * Sort
              */
             if (null != sortField) {
-                org.apache.commons.logging.LogFactory.getLog(TwitterMessagingMessageAccess.class).warn("Sort not yet supported");
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(TwitterMessagingMessageAccess.class)).warn("Sort not yet supported");
             }
             /*
              * Return
@@ -267,7 +270,7 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
 
     /**
      * Converts specified strings to an array of <code>long</code>.
-     * 
+     *
      * @param strings The strings
      * @return An array of <code>long</code>
      */
@@ -282,29 +285,29 @@ public final class TwitterMessagingMessageAccess implements MessagingMessageAcce
         return retval;
     }
 
-    /**
-     * Converts specified numbers to an array of <code>String</code>.
-     * 
-     * @param longs The numbers
-     * @return An array of <code>String</code>
-     */
-    private static final String[] longs2strings(final long[] longs) {
-        if (null == longs) {
-            return null;
-        }
-        final String[] retval = new String[longs.length];
-        for (int i = 0; i < retval.length; i++) {
-            final long l = longs[i];
-            if (-1 == l) {
-                retval[i] = null;
-            } else {
-                retval[i] = String.valueOf(longs[i]);
-            }
-        }
-        return retval;
-    }
+//    /**
+//     * Converts specified numbers to an array of <code>String</code>.
+//     *
+//     * @param longs The numbers
+//     * @return An array of <code>String</code>
+//     */
+//    private static final String[] longs2strings(final long[] longs) {
+//        if (null == longs) {
+//            return null;
+//        }
+//        final String[] retval = new String[longs.length];
+//        for (int i = 0; i < retval.length; i++) {
+//            final long l = longs[i];
+//            if (-1 == l) {
+//                retval[i] = null;
+//            } else {
+//                retval[i] = String.valueOf(longs[i]);
+//            }
+//        }
+//        return retval;
+//    }
 
-    public MessagingContent resolveContent(String folder, String id, String referenceId) throws MessagingException {
+    public MessagingContent resolveContent(final String folder, final String id, final String referenceId) throws MessagingException {
         throw new UnsupportedOperationException();
     }
 
