@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,21 +49,20 @@
 
 package com.openexchange.messaging.twitter;
 
-import static com.openexchange.messaging.twitter.FormStrings.FORM_LABEL_LOGIN;
-import static com.openexchange.messaging.twitter.FormStrings.FORM_LABEL_PASSWORD;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.Set;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
 import com.openexchange.datatypes.genericonf.FormElement;
+import com.openexchange.datatypes.genericonf.ReadOnlyDynamicFormDescription;
 import com.openexchange.messaging.MessagingAccountAccess;
 import com.openexchange.messaging.MessagingAccountManager;
 import com.openexchange.messaging.MessagingAccountTransport;
 import com.openexchange.messaging.MessagingAction;
 import com.openexchange.messaging.MessagingException;
+import com.openexchange.messaging.MessagingPermission;
 import com.openexchange.messaging.MessagingService;
-import com.openexchange.messaging.generic.DefaultMessagingAccountManager;
-import com.openexchange.messaging.generic.ReadOnlyDynamicFormDescription;
 import com.openexchange.session.Session;
 
 /**
@@ -73,12 +72,11 @@ import com.openexchange.session.Session;
  */
 public final class TwitterMessagingService implements MessagingService {
 
-    private static final List<MessagingAction> ACTIONS =
-        Collections.unmodifiableList(Arrays.asList(
-            new MessagingAction(TwitterConstants.TYPE_RETWEET, MessagingAction.Type.STORAGE, TwitterConstants.TYPE_TWEET),
-            new MessagingAction(TwitterConstants.TYPE_RETWEET_NEW, MessagingAction.Type.STORAGE),
-            new MessagingAction(TwitterConstants.TYPE_DIRECT_MESSAGE, MessagingAction.Type.STORAGE, TwitterConstants.TYPE_TWEET),
-            new MessagingAction(TwitterConstants.TYPE_TWEET, MessagingAction.Type.MESSAGE)));
+    private static final List<MessagingAction> ACTIONS = Collections.unmodifiableList(Arrays.asList(
+        new MessagingAction(TwitterConstants.TYPE_RETWEET, MessagingAction.Type.STORAGE, TwitterConstants.TYPE_TWEET),
+        new MessagingAction(TwitterConstants.TYPE_RETWEET_NEW, MessagingAction.Type.STORAGE),
+        new MessagingAction(TwitterConstants.TYPE_DIRECT_MESSAGE, MessagingAction.Type.STORAGE, TwitterConstants.TYPE_TWEET),
+        new MessagingAction(TwitterConstants.TYPE_TWEET, MessagingAction.Type.MESSAGE)));
 
     private static final String ID = "com.openexchange.messaging.twitter";
 
@@ -106,11 +104,19 @@ public final class TwitterMessagingService implements MessagingService {
      */
     public TwitterMessagingService() {
         super();
-        accountManager = new DefaultMessagingAccountManager(ID);
+        accountManager = new TwitterMessagingAccountManager(this);
         final DynamicFormDescription tmpDescription = new DynamicFormDescription();
-        tmpDescription.add(FormElement.input(TwitterConstants.TWITTER_LOGIN, FORM_LABEL_LOGIN, true, ""));
-        tmpDescription.add(FormElement.password(TwitterConstants.TWITTER_PASSWORD, FORM_LABEL_PASSWORD, true, ""));
-        this.formDescription = new ReadOnlyDynamicFormDescription(tmpDescription);
+        /*
+         * API & secret key
+         */
+        final FormElement oauthAccount = FormElement.custom("oauthAccount", "account", FormStrings.ACCOUNT_LABEL);
+        oauthAccount.setOption("type", "com.openexchange.oauth.twitter");
+        tmpDescription.add(oauthAccount);
+        formDescription = new ReadOnlyDynamicFormDescription(tmpDescription);
+    }
+
+    public Set<String> getSecretProperties() {
+        return Collections.emptySet();
     }
 
     public MessagingAccountAccess getAccountAccess(final int accountId, final Session session) throws MessagingException {
@@ -140,4 +146,16 @@ public final class TwitterMessagingService implements MessagingService {
     public DynamicFormDescription getFormDescription() {
         return formDescription;
     }
+
+    public static int[] getStaticRootPerms() {
+        return new int[] {MessagingPermission.READ_FOLDER,
+            MessagingPermission.READ_ALL_OBJECTS,
+            MessagingPermission.NO_PERMISSIONS,
+            MessagingPermission.DELETE_OWN_OBJECTS};
+    }
+
+    public int[] getStaticRootPermissions() {
+        return getStaticRootPerms();
+    }
+
 }
